@@ -1,5 +1,8 @@
 import smtplib
 import random
+import subprocess
+import os
+import shutil
 from pytube import YouTube
 import playsound
 
@@ -12,7 +15,11 @@ def email_bot(send_addr, password, recv_addr, body, server, port, sub='No Subjec
 
         smtp.login(send_addr, password)
 
-        final_msg = f'Subject: {sub}\n\n {body}'
+        sub_msg = 'Subject: {}'.format(sub)
+        body_msg = '\n\n {}'.format(body)
+
+        final_msg = sub_msg + body_msg
+
         smtp.sendmail(send_addr, recv_addr, final_msg)
         return True
 
@@ -24,7 +31,7 @@ def email_address_slicer(full_addr):
     return username, domain
 
 
-def yt_downloader(video_url):
+def yt_downloader(video_url, output_path=str(os.getcwd()), filename='video'):
     yt = YouTube(video_url)
     if yt.streams.first().download():
         return True
@@ -47,3 +54,8 @@ def timer(seconds, audio_file):
         if time <= 0:
             playsound.playsound(audio_file)
         time = time - 1
+
+def start_app(drive, exe_path):
+    command = drive + ': && ' + exe_path
+    if subprocess.run(command, shell=True):
+        return True
\ No newline at end of file
